This directory contains files required for nilearn reporting.

```
├── css                                  # css files
│   ├── head.css
│   └── repor.css
├── html                                 # templates for HTML files
│   ├── body_base.jinja
│   ├── head.jinja
│   ├── partials
│   │   └── warnings.jinja
│   └── glm
│        ├── partials
│        │   ├── method_section.jinja
│        │   └── navbar.jinja
│        └── body_glm.jinja
├── js
│   └── carousel.js
└── README.md
```
